rulebase.rules.sentence\_segmentation.const module
==================================================

.. automodule:: rulebase.rules.sentence_segmentation.const
    :members:
    :undoc-members:
    :show-inheritance:
